[![PyPI Package latest release](https://img.shields.io/pypi/v/sarajas.svg)][1]
[![PyPI Wheel](https://img.shields.io/pypi/wheel/sarajas.svg)][1]
[![Supported versions](https://img.shields.io/pypi/pyversions/sarajas.svg)][1]
[![Supported implementations](https://img.shields.io/pypi/implementation/sarajas.svg)][1]

# Sarajas <!-- omit in toc -->

Sarajas is a graph database program to allow mixed file type data in a database. Far from ready to be used.

## Table of Contents <!-- omit in toc -->

- [Quick start guide](#quick-start-guide)
    - [The first steps](#the-first-steps)
        - [Installing](#installing)
        - [Importing](#importing)

# Quick start guide

Here's how you can start

## The first steps

### Installing

Install Sarajas with pip

```
pip install sarajas
```

### Importing

Import name is the same as install name, `sarajas`.

```python
import sarajas
```

Since the package is accessed often,  abbreviation `sr` is used. The abbreviation is used throughout this document.

```python
import sarajas as sr
```

# Changelog <!-- omit in toc -->

## 0.0.4 2024-07-17 <!-- omit in toc -->

- Initial publishing

[1]: <https://pypi.org/project/sarajas> "Project PyPI page"
